import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_wearecg12/healthrian_ble_support_for_wearecg12.dart';

class BlePage extends StatelessWidget {
  const BlePage({super.key});

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        /// express a received packet which contains ecg signal
        body: Column(
          children: [
            Observer(
              key: UniqueKey(),
              builder: (context) {
                return StreamBuilder(
                  stream: BLEManager().streams.bufferedPlotRTStreamEcg,
                  builder: (context, snapshot) {
                    if (!snapshot.hasData) return const SizedBox();

                    final s = StringBuffer();
                    for (final l in snapshot.data!.toList()) {
                      s.write('${l.last}\n');
                    }
                    return Text(s.toString());
                  },
                );
              },
            ),
          ],
        ),

        /// control panel
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().connectDevice();
                await BLEManager().registerCharacteristics();
              },
              child: const Icon(Icons.bluetooth),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().disconnectDevice();
              },
              child: const Icon(Icons.bluetooth_disabled),
            ),
            FloatingActionButton(
              onPressed: () async {
                await BLEManager().startMeasurementEcg();
              },
              child: const Icon(Icons.play_arrow),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().pauseMeasurementEcg();
              },
              child: const Icon(Icons.pause),
            ),
            FloatingActionButton(
              onPressed: () {
                BLEManager().stopMeasurementEcg();
              },
              child: const Icon(Icons.stop),
            ),
          ],
        ),
      ),
    );
  }
}
